package
Version:
v0.0.0-...-e653932
Opens a new window with list of versions in this module.
Published: Jun 26, 2020
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Node struct {
Value interface{}
Left *Node
Right *Node
}
func NewCompleteTree(data []int) *Tree
func (t *Tree) PreOrderTraversal()
Source Files
¶
Click to show internal directories.
Click to hide internal directories.